@@ -1,10 +1,14 @@
 # 1 "utils/domainstate.mli.c"
-# 1 "<built-in>"
-# 1 "<command-line>"
-# 1 "utils/domainstate.mli.c"
+# 1 "<built-in>" 1
+# 1 "<built-in>" 3
+# 359 "<built-in>" 3
+# 1 "<command line>" 1
+# 1 "<built-in>" 2
+# 1 "utils/domainstate.mli.c" 2
 # 17 "utils/domainstate.mli.c"
 type t =
 
+
 # 1 "runtime/caml/domain_state.tbl" 1
 # 17 "runtime/caml/domain_state.tbl"
 | Domain_young_ptr
@@ -65,6 +69,13 @@ type t =
 | Domain_stat_top_heap_wsz
 | Domain_stat_compactions
 | Domain_stat_heap_chunks
+
+
+| Domain_eventlog_startup_timestamp
+| Domain_eventlog_startup_pid
+| Domain_eventlog_paused
+| Domain_eventlog_enabled
+| Domain_eventlog_out
 # 20 "utils/domainstate.mli.c" 2
 
 
